Split out isrg from ssr and reorient build graph to make interpreter build 2x faster (#2969)

* split out isrg and core-types to speed up interpreter build
This commit is contained in:
Jonathan Kelley authored and GitHub committed 2024-09-16 16:49:06 -07:00
1 parent f0d814fede
commit 143ad749ea
28 files changed
+197 -231

No files matched your search

+5 -1
View File
@@ -243,7 +243,11 @@ impl Renderer {
// then write any listeners
for name in accumulated_listeners.drain(..) {
write!(buf, ",{}:", &name[2..])?;
write!(buf, "{}", dioxus_html::event_bubbles(&name[2..]) as u8)?;
write!(
buf,
"{}",
dioxus_core_types::event_bubbles(&name[2..]) as u8
)?;
}
}